#  Copyright (c) 2020, Apple Inc. All rights reserved.
#
#  Use of this source code is governed by a BSD-3-clause license that can be
#  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
from coremltools.converters.mil.mil.ops.registry import \
    SSAOpRegistry as _SSAOpRegistry

register_op = _SSAOpRegistry.register_op
